==> json-joy-1.10.0.tgz: package/esm/json-pack/cbor/CborEncoder.js <==
import { isFloat32 } from '../../util/buffers/isFloat32';
import { isUint8Array } from '../../util/buffers/isUint8Array';
import { CborEncoderFast } from './CborEncoderFast';
const isSafeInteger = Number.isSafeInteger;
export class CborEncoder extends CborEncoderFast {
    encode(value) {
        this.writer.reset();
        this.writeAny(value);
        return this.writer.flush();
    }
    writeAny(value) {
        switch (value) {
            case null:
                return this.writer.u8(0xf6);
            case false:
                return this.writer.u8(0xf4);
            case true:
                return this.writer.u8(0xf5);
            case undefined:
                return this.writer.u8(0xf7);
        }
        if (value instanceof Array)
            return this.writeArr(value);
        switch (typeof value) {
            case 'number':
                return this.encodeNumber(value);
            case 'string':
                return this.writeStr(value);
            case 'object': {
                if (isUint8Array(value))
                    return this.writeBin(value);
                if (value instanceof Map)
                    return this.writeMap(value);
                return this.writeObj(value);
            }
            case 'bigint':
                return this.encodeBigInteger(value);
        }
    }
    encodeNumber(num) {
        if (isSafeInteger(num))
            this.encodeInteger(num);
        else if (typeof num === 'bigint')
            this.encodeBigInteger(num);
        else
            this.writeFloat(num);
    }
    encodeBigInteger(int) {
        if (int >= 0)
            this.encodeBigUint(int);
        else
            this.encodeBigNint(int);
    }
    encodeBigUint(uint) {
        switch (true) {
            case uint <= 23:
                this.writer.u8(0 + Number(uint));
                break;
            case uint <= 0xff:
                this.writer.u16((0x18 << 8) + Number(uint));
                break;
            case uint <= 0xffff:
                this.writer.u8u16(0x19, Number(uint));
                break;
            case uint <= 0xffffffff:
                this.writer.u8u32(0x1a, Number(uint));
                break;
            default: {
                this.writer.u8u64(0x1b, uint);
                break;
            }
        }
    }
    encodeBigNint(int) {
        const uint = -BigInt(1) - int;
        switch (true) {
            case uint <= 24:
                this.writer.u8(32 + Number(uint));
                break;
            case uint <= 0xff:
                this.writer.u16((0x38 << 8) + Number(uint));
                break;
            case uint <= 0xffff:
                this.writer.u8u16(0x39, Number(uint));
                break;
            case uint <= 0xffffffff:
                this.writer.u8u32(0x3a, Number(uint));
                break;
            default:
                this.writer.u8u64(0x3b, uint);
                break;
        }
    }
    writeFloat(float) {
        if (isFloat32(float))
            this.writer.u8f32(0xfa, float);
        else
            this.writer.u8f64(0xfb, float);
    }
    writeMap(map) {
        this.writeMapHdr(map.size);
        map.forEach((value, key) => {
            this.writeAny(key);
            this.writeAny(value);
        });
    }
}

==> json-joy-9.3.0.tgz: package/esm/json-pack/cbor/CborEncoder.js <==
import { isFloat32 } from '../../util/buffers/isFloat32';
import { CborEncoderFast } from './CborEncoderFast';
const isSafeInteger = Number.isSafeInteger;
export class CborEncoder extends CborEncoderFast {
    writeAny(value) {
        switch (typeof value) {
            case 'number':
                return this.writeNumber(value);
            case 'string':
                return this.writeStr(value);
            case 'boolean':
                return this.writer.u8(0xf4 + +value);
            case 'object': {
                if (!value)
                    return this.writer.u8(0xf6);
                const constructor = value.constructor;
                switch (constructor) {
                    case Array:
                        return this.writeArr(value);
                    case Uint8Array:
                        return this.writeBin(value);
                    case Map:
                        return this.writeMap(value);
                    default:
                        return this.writeObj(value);
                }
            }
            case 'undefined':
                return this.writer.u8(0xf7);
            case 'bigint':
                return this.writeBigInt(value);
        }
    }
    writeNumber(num) {
        if (isSafeInteger(num))
            this.writeInteger(num);
        else if (typeof num === 'bigint')
            this.writeBigInt(num);
        else
            this.writeFloat(num);
    }
    writeBigInt(int) {
        if (int >= 0)
            this.writeBigUint(int);
        else
            this.writeBigSint(int);
    }
    writeBigUint(uint) {
        switch (true) {
            case uint <= 23:
                this.writer.u8(0 + Number(uint));
                break;
            case uint <= 0xff:
                this.writer.u16((0x18 << 8) + Number(uint));
                break;
            case uint <= 0xffff:
                this.writer.u8u16(0x19, Number(uint));
                break;
            case uint <= 0xffffffff:
                this.writer.u8u32(0x1a, Number(uint));
                break;
            default: {
                this.writer.u8u64(0x1b, uint);
                break;
            }
        }
    }
    writeBigSint(int) {
        const uint = -BigInt(1) - int;
        switch (true) {
            case uint <= 24:
                this.writer.u8(32 + Number(uint));
                break;
            case uint <= 0xff:
                this.writer.u16((0x38 << 8) + Number(uint));
                break;
            case uint <= 0xffff:
                this.writer.u8u16(0x39, Number(uint));
                break;
            case uint <= 0xffffffff:
                this.writer.u8u32(0x3a, Number(uint));
                break;
            default:
                this.writer.u8u64(0x3b, uint);
                break;
        }
    }
    writeFloat(float) {
        if (isFloat32(float))
            this.writer.u8f32(0xfa, float);
        else
            this.writer.u8f64(0xfb, float);
    }
    writeMap(map) {
        this.writeMapHdr(map.size);
        map.forEach((value, key) => {
            this.writeAny(key);
            this.writeAny(value);
        });
    }
}
